scxpand.hyperopt.param\_grids
=============================

.. automodule:: scxpand.hyperopt.param_grids

   
   .. rubric:: Functions

   .. autosummary::
   
      configure_ae_trial_params
      configure_lightgbm_trial_params
      configure_logistic_trial_params
      configure_mlp_trial_params
      configure_svm_trial_params
      create_optimized_lr_scheduler_config
   